==> com.liferay.frontend.editor.tinymce.web-3.0.8.jar: META-INF/resources/_diffs/langs/fr_FR.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('fr_FR', {
	Cut: 'Couper',
	'Heading 5': 'En-t\u00eate 5',
	'Header 2': 'Titre 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		"Votre navigateur ne supporte pas la copie directe. Merci d'utiliser les touches Ctrl+X/C/V.",
	'Heading 4': 'En-t\u00eate 4',
	Div: 'Div',
	'Heading 2': 'En-t\u00eate 2',
	Paste: 'Coller',
	Close: 'Fermer',
	'Font Family': 'Polices de caract\u00e8res',
	Pre: 'Pre',
	'Align right': 'Aligner \u00e0 droite',
	'New document': 'Nouveau document',
	Blockquote: 'Citation',
	'Numbered list': 'Num\u00e9rotation',
	'Heading 1': 'En-t\u00eate 1',
	Headings: 'En-t\u00eates',
	'Increase indent': 'Augmenter le retrait',
	Formats: 'Formats',
	Headers: 'Titres',
	'Select all': 'Tout s\u00e9lectionner',
	'Header 3': 'Titre 3',
	Blocks: 'Blocs',
	Undo: 'Annuler',
	Strikethrough: 'Barr\u00e9',
	'Bullet list': 'Puces',
	'Header 1': 'Titre 1',
	Superscript: 'Exposant',
	'Clear formatting': 'Effacer la mise en forme',
	'Font Sizes': 'Tailles de la police',
	Subscript: 'Indice',
	'Header 6': 'Titre 6',
	Redo: 'R\u00e9tablir',
	Paragraph: 'Paragraphe',
	Ok: 'Ok',
	Bold: 'Gras',
	Code: 'Code',
	Italic: 'Italique',
	'Align center': 'Aligner au centre',
	'Header 5': 'Titre 5',
	'Heading 6': 'En-t\u00eate 6',
	'Heading 3': 'En-t\u00eate 3',
	'Decrease indent': 'Diminuer le retrait',
	'Header 4': 'Titre 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Le presse-papiers est maintenant en mode "texte plein". Les contenus seront coll\u00e9s sans retenir les formatages jusqu\'\u00e0 ce que vous d\u00e9sactiviez cette option.',
	Underline: 'Soulign\u00e9',
	Cancel: 'Annuler',
	Justify: 'Justifi\u00e9',
	Inline: 'En ligne',
	Copy: 'Copier',
	'Align left': 'Aligner \u00e0 gauche',
	'Visual aids': 'Aides visuelle',
	'Lower Greek': 'Grec minuscule',
	Square: 'Carr\u00e9',
	Default: 'Par d\u00e9faut',
	'Lower Alpha': 'Alpha minuscule',
	Circle: 'Cercle',
	Disc: 'Disque',
	'Upper Alpha': 'Alpha majuscule',
	'Upper Roman': 'Romain majuscule',
	'Lower Roman': 'Romain minuscule',
	Name: 'Nom',
	Anchor: 'Ancre',
	'You have unsaved changes are you sure you want to navigate away?':
		'Vous avez des modifications non enregistr\u00e9es, \u00eates-vous s\u00fbr de quitter la page?',
	'Restore last draft': 'Restaurer le dernier brouillon',
	'Special character': 'Caract\u00e8res sp\u00e9ciaux',
	'Source code': 'Code source',
	Color: 'Couleur',
	'Right to left': 'Droite \u00e0 gauche',
	'Left to right': 'Gauche \u00e0 droite',
	Emoticons: 'Emotic\u00f4nes',
	Robots: 'Robots',
	'Document properties': 'Propri\u00e9t\u00e9 du document',
	Title: 'Titre',
	Keywords: 'Mots-cl\u00e9s',
	Encoding: 'Encodage',
	Description: 'Description',
	Author: 'Auteur',
	Fullscreen: 'Plein \u00e9cran',
	'Horizontal line': 'Ligne horizontale',
	'Horizontal space': 'Espacement horizontal',
	'Insert/edit image': 'Ins\u00e9rer/\u00e9diter une image',
	General: 'G\u00e9n\u00e9ral',
	Advanced: 'Avanc\u00e9',
	Source: 'Source',
	Border: 'Bordure',
	'Constrain proportions': 'Contraindre les proportions',
	'Vertical space': 'Espacement vertical',
	'Image description': "Description de l'image",
	Style: 'Style',
	Dimensions: 'Dimensions',
	'Insert image': 'Ins\u00e9rer une image',
	'Insert date/time': 'Ins\u00e9rer date/heure',
	'Remove link': 'Enlever le lien',
	Url: 'Url',
	'Text to display': 'Texte \u00e0 afficher',
	Anchors: 'Ancres',
	'Insert link': 'Ins\u00e9rer un lien',
	'New window': 'Nouvelle fen\u00eatre',
	None: 'n/a',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		"L'URL que vous avez entr\u00e9e semble \u00eatre un lien externe. Voulez-vous ajouter le pr\u00e9fixe http:// n\u00e9cessaire?",
	Target: 'Cible',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		"L'URL que vous avez entr\u00e9e semble \u00eatre une adresse e-mail. Voulez-vous ajouter le pr\u00e9fixe mailto: n\u00e9cessaire?",
	'Insert/edit link': 'Ins\u00e9rer/\u00e9diter un lien',
	'Insert/edit video': 'Ins\u00e9rer/\u00e9diter une vid\u00e9o',
	Poster: 'Publier',
	'Alternative source': 'Source alternative',
	'Paste your embed code below:':
		"Collez votre code d'int\u00e9gration ci-dessous :",
	'Insert video': 'Ins\u00e9rer une vid\u00e9o',
	Embed: 'Ins\u00e9rer',
	'Nonbreaking space': 'Espace ins\u00e9cable',
	'Page break': 'Saut de page',
	'Paste as text': 'Coller comme texte',
	Preview: 'Pr\u00e9visualiser',
	Print: 'Imprimer',
	Save: 'Enregistrer',
	'Could not find the specified string.':
		'Impossible de trouver la cha\u00eene sp\u00e9cifi\u00e9e.',
	Replace: 'Remplacer',
	Next: 'Suiv',
	'Whole words': 'Mots entiers',
	'Find and replace': 'Trouver et remplacer',
	'Replace with': 'Remplacer par',
	Find: 'Chercher',
	'Replace all': 'Tout remplacer',
	'Match case': 'Respecter la casse',
	Prev: 'Pr\u00e9c ',
	Spellcheck: 'V\u00e9rification orthographique',
	Finish: 'Finie',
	'Ignore all': 'Tout ignorer',
	Ignore: 'Ignorer',
	'Add to Dictionary': 'Ajouter au dictionnaire',
	'Insert row before': 'Ins\u00e9rer une ligne avant',
	Rows: 'Lignes',
	Height: 'Hauteur',
	'Paste row after': 'Coller la ligne apr\u00e8s',
	Alignment: 'Alignement',
	'Border color': 'Couleur de la bordure',
	'Column group': 'Groupe de colonnes',
	Row: 'Ligne',
	'Insert column before': 'Ins\u00e9rer une colonne avant',
	'Split cell': 'Diviser la cellule',
	'Cell padding': 'Espacement interne cellule',
	'Cell spacing': 'Espacement inter-cellulles',
	'Row type': 'Type de ligne',
	'Insert table': 'Ins\u00e9rer un tableau',
	Body: 'Corps',
	Caption: 'Titre',
	Footer: 'Pied',
	'Delete row': 'Effacer la ligne',
	'Paste row before': 'Coller la ligne avant',
	Scope: 'Etendue',
	'Delete table': 'Supprimer le tableau',
	'H Align': 'Alignement H',
	Top: 'Haut',
	'Header cell': "Cellule d'en-t\u00eate",
	Column: 'Colonne',
	'Row group': 'Groupe de lignes',
	Cell: 'Cellule',
	Middle: 'Milieu',
	'Cell type': 'Type de cellule',
	'Copy row': 'Copier la ligne',
	'Row properties': 'Propri\u00e9t\u00e9s de la ligne',
	'Table properties': 'Propri\u00e9t\u00e9s du tableau',
	Bottom: 'Bas',
	'V Align': 'Alignement V',
	Header: 'En-t\u00eate',
	Right: 'Droite',
	'Insert column after': 'Ins\u00e9rer une colonne apr\u00e8s',
	Cols: 'Colonnes',
	'Insert row after': 'Ins\u00e9rer une ligne apr\u00e8s',
	Width: 'Largeur',
	'Cell properties': 'Propri\u00e9t\u00e9s de la cellule',
	Left: 'Gauche',
	'Cut row': 'Couper la ligne',
	'Delete column': 'Effacer la colonne',
	Center: 'Centr\u00e9',
	'Merge cells': 'Fusionner les cellules',
	'Insert template': 'Ajouter un th\u00e8me',
	Templates: 'Th\u00e8mes',
	'Background color': "Couleur d'arri\u00e8re-plan",
	'Custom...': 'Personnalis\u00e9...',
	'Custom color': 'Couleur personnalis\u00e9e',
	'No color': 'Aucune couleur',
	'Text color': 'Couleur du texte',
	'Show blocks': 'Afficher les blocs',
	'Show invisible characters': 'Afficher les caract\u00e8res invisibles',
	'Words: {0}': 'Mots : {0}',
	Insert: 'Ins\u00e9rer',
	File: 'Fichier',
	Edit: 'Editer',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		"Zone Texte Riche. Appuyer sur ALT-F9 pour le menu. Appuyer sur ALT-F10 pour la barre d'outils. Appuyer sur ALT-0 pour de l'aide.",
	Tools: 'Outils',
	View: 'Voir',
	Table: 'Tableau',
	Format: 'Format'
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/fr_FR.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('fr_FR', {
	'Cut': 'Couper',
	'Heading 5': 'En-t\u00eate 5',
	'Header 2': 'Titre 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		"Votre navigateur ne supporte pas la copie directe. Merci d'utiliser les touches Ctrl+X/C/V.",
	'Heading 4': 'En-t\u00eate 4',
	'Div': 'Div',
	'Heading 2': 'En-t\u00eate 2',
	'Paste': 'Coller',
	'Close': 'Fermer',
	'Font Family': 'Polices de caract\u00e8res',
	'Pre': 'Pre',
	'Align right': 'Aligner \u00e0 droite',
	'New document': 'Nouveau document',
	'Blockquote': 'Citation',
	'Numbered list': 'Num\u00e9rotation',
	'Heading 1': 'En-t\u00eate 1',
	'Headings': 'En-t\u00eates',
	'Increase indent': 'Augmenter le retrait',
	'Formats': 'Formats',
	'Headers': 'Titres',
	'Select all': 'Tout s\u00e9lectionner',
	'Header 3': 'Titre 3',
	'Blocks': 'Blocs',
	'Undo': 'Annuler',
	'Strikethrough': 'Barr\u00e9',
	'Bullet list': 'Puces',
	'Header 1': 'Titre 1',
	'Superscript': 'Exposant',
	'Clear formatting': 'Effacer la mise en forme',
	'Font Sizes': 'Tailles de la police',
	'Subscript': 'Indice',
	'Header 6': 'Titre 6',
	'Redo': 'R\u00e9tablir',
	'Paragraph': 'Paragraphe',
	'Ok': 'Ok',
	'Bold': 'Gras',
	'Code': 'Code',
	'Italic': 'Italique',
	'Align center': 'Aligner au centre',
	'Header 5': 'Titre 5',
	'Heading 6': 'En-t\u00eate 6',
	'Heading 3': 'En-t\u00eate 3',
	'Decrease indent': 'Diminuer le retrait',
	'Header 4': 'Titre 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Le presse-papiers est maintenant en mode "texte plein". Les contenus seront coll\u00e9s sans retenir les formatages jusqu\'\u00e0 ce que vous d\u00e9sactiviez cette option.',
	'Underline': 'Soulign\u00e9',
	'Cancel': 'Annuler',
	'Justify': 'Justifi\u00e9',
	'Inline': 'En ligne',
	'Copy': 'Copier',
	'Align left': 'Aligner \u00e0 gauche',
	'Visual aids': 'Aides visuelle',
	'Lower Greek': 'Grec minuscule',
	'Square': 'Carr\u00e9',
	'Default': 'Par d\u00e9faut',
	'Lower Alpha': 'Alpha minuscule',
	'Circle': 'Cercle',
	'Disc': 'Disque',
	'Upper Alpha': 'Alpha majuscule',
	'Upper Roman': 'Romain majuscule',
	'Lower Roman': 'Romain minuscule',
	'Name': 'Nom',
	'Anchor': 'Ancre',
	'You have unsaved changes are you sure you want to navigate away?':
		'Vous avez des modifications non enregistr\u00e9es, \u00eates-vous s\u00fbr de quitter la page?',
	'Restore last draft': 'Restaurer le dernier brouillon',
	'Special character': 'Caract\u00e8res sp\u00e9ciaux',
	'Source code': 'Code source',
	'Color': 'Couleur',
	'Right to left': 'Droite \u00e0 gauche',
	'Left to right': 'Gauche \u00e0 droite',
	'Emoticons': 'Emotic\u00f4nes',
	'Robots': 'Robots',
	'Document properties': 'Propri\u00e9t\u00e9 du document',
	'Title': 'Titre',
	'Keywords': 'Mots-cl\u00e9s',
	'Encoding': 'Encodage',
	'Description': 'Description',
	'Author': 'Auteur',
	'Fullscreen': 'Plein \u00e9cran',
	'Horizontal line': 'Ligne horizontale',
	'Horizontal space': 'Espacement horizontal',
	'Insert/edit image': 'Ins\u00e9rer/\u00e9diter une image',
	'General': 'G\u00e9n\u00e9ral',
	'Advanced': 'Avanc\u00e9',
	'Source': 'Source',
	'Border': 'Bordure',
	'Constrain proportions': 'Contraindre les proportions',
	'Vertical space': 'Espacement vertical',
	'Image description': "Description de l'image",
	'Style': 'Style',
	'Dimensions': 'Dimensions',
	'Insert image': 'Ins\u00e9rer une image',
	'Insert date/time': 'Ins\u00e9rer date/heure',
	'Remove link': 'Enlever le lien',
	'Url': 'Url',
	'Text to display': 'Texte \u00e0 afficher',
	'Anchors': 'Ancres',
	'Insert link': 'Ins\u00e9rer un lien',
	'New window': 'Nouvelle fen\u00eatre',
	'None': 'n/a',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		"L'URL que vous avez entr\u00e9e semble \u00eatre un lien externe. Voulez-vous ajouter le pr\u00e9fixe http:// n\u00e9cessaire?",
	'Target': 'Cible',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		"L'URL que vous avez entr\u00e9e semble \u00eatre une adresse e-mail. Voulez-vous ajouter le pr\u00e9fixe mailto: n\u00e9cessaire?",
	'Insert/edit link': 'Ins\u00e9rer/\u00e9diter un lien',
	'Insert/edit video': 'Ins\u00e9rer/\u00e9diter une vid\u00e9o',
	'Poster': 'Publier',
	'Alternative source': 'Source alternative',
	'Paste your embed code below:':
		"Collez votre code d'int\u00e9gration ci-dessous :",
	'Insert video': 'Ins\u00e9rer une vid\u00e9o',
	'Embed': 'Ins\u00e9rer',
	'Nonbreaking space': 'Espace ins\u00e9cable',
	'Page break': 'Saut de page',
	'Paste as text': 'Coller comme texte',
	'Preview': 'Pr\u00e9visualiser',
	'Print': 'Imprimer',
	'Save': 'Enregistrer',
	'Could not find the specified string.':
		'Impossible de trouver la cha\u00eene sp\u00e9cifi\u00e9e.',
	'Replace': 'Remplacer',
	'Next': 'Suiv',
	'Whole words': 'Mots entiers',
	'Find and replace': 'Trouver et remplacer',
	'Replace with': 'Remplacer par',
	'Find': 'Chercher',
	'Replace all': 'Tout remplacer',
	'Match case': 'Respecter la casse',
	'Prev': 'Pr\u00e9c ',
	'Spellcheck': 'V\u00e9rification orthographique',
	'Finish': 'Finie',
	'Ignore all': 'Tout ignorer',
	'Ignore': 'Ignorer',
	'Add to Dictionary': 'Ajouter au dictionnaire',
	'Insert row before': 'Ins\u00e9rer une ligne avant',
	'Rows': 'Lignes',
	'Height': 'Hauteur',
	'Paste row after': 'Coller la ligne apr\u00e8s',
	'Alignment': 'Alignement',
	'Border color': 'Couleur de la bordure',
	'Column group': 'Groupe de colonnes',
	'Row': 'Ligne',
	'Insert column before': 'Ins\u00e9rer une colonne avant',
	'Split cell': 'Diviser la cellule',
	'Cell padding': 'Espacement interne cellule',
	'Cell spacing': 'Espacement inter-cellulles',
	'Row type': 'Type de ligne',
	'Insert table': 'Ins\u00e9rer un tableau',
	'Body': 'Corps',
	'Caption': 'Titre',
	'Footer': 'Pied',
	'Delete row': 'Effacer la ligne',
	'Paste row before': 'Coller la ligne avant',
	'Scope': 'Etendue',
	'Delete table': 'Supprimer le tableau',
	'H Align': 'Alignement H',
	'Top': 'Haut',
	'Header cell': "Cellule d'en-t\u00eate",
	'Column': 'Colonne',
	'Row group': 'Groupe de lignes',
	'Cell': 'Cellule',
	'Middle': 'Milieu',
	'Cell type': 'Type de cellule',
	'Copy row': 'Copier la ligne',
	'Row properties': 'Propri\u00e9t\u00e9s de la ligne',
	'Table properties': 'Propri\u00e9t\u00e9s du tableau',
	'Bottom': 'Bas',
	'V Align': 'Alignement V',
	'Header': 'En-t\u00eate',
	'Right': 'Droite',
	'Insert column after': 'Ins\u00e9rer une colonne apr\u00e8s',
	'Cols': 'Colonnes',
	'Insert row after': 'Ins\u00e9rer une ligne apr\u00e8s',
	'Width': 'Largeur',
	'Cell properties': 'Propri\u00e9t\u00e9s de la cellule',
	'Left': 'Gauche',
	'Cut row': 'Couper la ligne',
	'Delete column': 'Effacer la colonne',
	'Center': 'Centr\u00e9',
	'Merge cells': 'Fusionner les cellules',
	'Insert template': 'Ajouter un th\u00e8me',
	'Templates': 'Th\u00e8mes',
	'Background color': "Couleur d'arri\u00e8re-plan",
	'Custom...': 'Personnalis\u00e9...',
	'Custom color': 'Couleur personnalis\u00e9e',
	'No color': 'Aucune couleur',
	'Text color': 'Couleur du texte',
	'Show blocks': 'Afficher les blocs',
	'Show invisible characters': 'Afficher les caract\u00e8res invisibles',
	'Words: {0}': 'Mots : {0}',
	'Insert': 'Ins\u00e9rer',
	'File': 'Fichier',
	'Edit': 'Editer',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		"Zone Texte Riche. Appuyer sur ALT-F9 pour le menu. Appuyer sur ALT-F10 pour la barre d'outils. Appuyer sur ALT-0 pour de l'aide.",
	'Tools': 'Outils',
	'View': 'Voir',
	'Table': 'Tableau',
	'Format': 'Format',
});
